@@ -29,6 +29,7 @@
 #ifdef HAVE_MAEMO
 #include <hildon/hildon-find-toolbar.h>
 #include <hildon/hildon-banner.h>
+#include <hildon/hildon-text-view.h>
 #endif
 #endif
 
@@ -97,8 +98,12 @@ gboolean document_search_real(GtkWidget *textview, gint direction)
 	GtkTextIter iter, match_start, match_end;
 	gboolean res;
 	GtkSourceSearchFlags search_flags = GTK_SOURCE_SEARCH_VISIBLE_ONLY | GTK_SOURCE_SEARCH_TEXT_ONLY;
+#ifdef USE_HILDON
+	GtkTextBuffer *textbuffer = hildon_text_view_get_buffer(HILDON_TEXT_VIEW(textview));
+#else
 	GtkTextBuffer *textbuffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview));
-	
+#endif
+
 	if (!string_find)
 		return FALSE;
 	
@@ -165,11 +170,13 @@ static gint document_replace_real(GtkWidget *textview)
 	gint num = 0, offset;
 	GtkWidget *q_dialog = NULL;
 	GtkSourceSearchFlags search_flags = GTK_SOURCE_SEARCH_VISIBLE_ONLY | GTK_SOURCE_SEARCH_TEXT_ONLY;	
-	GtkTextBuffer *textbuffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview));
 #ifdef USE_HILDON
 	gchar *str;
+	GtkTextBuffer *textbuffer = hildon_text_view_get_buffer(HILDON_TEXT_VIEW(textview));
+#else
+	GtkTextBuffer *textbuffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview));
 #endif
-	
+
 	if (!match_case)
 		search_flags = search_flags | GTK_SOURCE_SEARCH_CASE_INSENSITIVE;
 	
@@ -326,11 +333,11 @@ static void toggle_check_all(GtkWidget *widget)
 
 #ifdef USE_HILDON
 static void on_find_search (GtkWidget *widget)
-{      
+{
 	g_free (string_find);
 
 	g_object_get (G_OBJECT(widget), "prefix", &string_find, NULL);
-	
+
 	if (strlen (string_find))
 		document_search_real (pub->mw->view, 0);
 }
@@ -339,10 +346,10 @@ GtkWidget *create_search_bar(GtkWidget *window)
 {
 	HildonFindToolbar *find_toolbar;
 
-	find_toolbar = HILDON_FIND_TOOLBAR (hildon_find_toolbar_new ("Find: "));
+	find_toolbar = HILDON_FIND_TOOLBAR (hildon_find_toolbar_new (NULL));
 	g_signal_connect (G_OBJECT(find_toolbar), "search",
 		G_CALLBACK (on_find_search), NULL);
-	
+
 	g_signal_connect(G_OBJECT(find_toolbar), "close",
 		G_CALLBACK(on_find_close), NULL);
 
@@ -365,12 +372,23 @@ gint run_dialog_search(GtkWidget *textview, gint mode)
 	gint res;
 	
 	if (mode)
+        {
+#ifdef USE_HILDON
+		GtkWidget *button;
+#endif
 		dialog = gtk_dialog_new_with_buttons(_("Replace"),
 			GTK_WINDOW(gtk_widget_get_toplevel(textview)),
 			GTK_DIALOG_DESTROY_WITH_PARENT,
 			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+#ifndef USE_HILDON
 			GTK_STOCK_FIND_AND_REPLACE, GTK_RESPONSE_OK,
+#endif
 			NULL);
+#ifdef USE_HILDON
+		button = gtk_dialog_add_button(GTK_DIALOG(dialog), GTK_STOCK_FIND_AND_REPLACE, GTK_RESPONSE_OK);
+		hildon_gtk_widget_set_theme_size(button, HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+#endif
+        }
 	else
 #ifndef USE_HILDON
 		dialog = gtk_dialog_new_with_buttons(_("Find"),
@@ -382,11 +400,11 @@ gint run_dialog_search(GtkWidget *textview, gint mode)
 #else
 	{
 		gtk_widget_show (pub->mw->find_toolbar);
-		gtk_widget_grab_focus (pub->mw->find_toolbar);
+		hildon_find_toolbar_highlight_entry (pub->mw->find_toolbar, TRUE);
 	}
 
 	if (mode) {
-#endif			
+#endif
 	gtk_dialog_set_has_separator(GTK_DIALOG(dialog), FALSE);
 	
 	table = gtk_table_new(mode + 2, 2, FALSE);
@@ -420,19 +438,28 @@ gint run_dialog_search(GtkWidget *textview, gint mode)
 		G_CALLBACK(toggle_sensitivity), NULL);
 #endif
 #if SEARCH_HISTORY
+#ifdef USE_HILDON
+	 buffer = hildon_text_view_get_buffer (HILDON_TEXT_VIEW (textview));
+#else
 	 buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (textview));
+#endif
 	 if (gtk_text_buffer_get_selection_bounds (buffer, &start_iter, &end_iter)) {
  		if (string_find != NULL)
 		 g_free(string_find);
 		string_find = gtk_text_buffer_get_text (buffer, &start_iter, &end_iter,
 			FALSE);
 		gtk_entry_set_text(GTK_ENTRY(entry_find), string_find);
+		gtk_dialog_set_response_sensitive(GTK_DIALOG(dialog),
+			GTK_RESPONSE_OK, TRUE);
 	 }
 	 else
  		gtk_entry_set_text(GTK_ENTRY(entry_find), "");
 #else
-	 if (string_find) 
+	 if (string_find) {
 		 gtk_entry_set_text(GTK_ENTRY(entry_find), string_find);
+		 gtk_dialog_set_response_sensitive(GTK_DIALOG(dialog),
+			GTK_RESPONSE_OK, TRUE);
+	}
 #endif
 	if (mode) {
 		label_replace = gtk_label_new_with_mnemonic(_("Re_place with:"));
@@ -518,9 +545,13 @@ void run_dialog_jump_to(GtkWidget *textview)
 	GtkAdjustment *spinner_adj;
 	GtkTextIter iter;
 	gint num, max_num;
-	
+
+#ifdef USE_HILDON
+	GtkTextBuffer *textbuffer = hildon_text_view_get_buffer(HILDON_TEXT_VIEW(textview));
+#else
 	GtkTextBuffer *textbuffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview));
-	
+#endif
+
 	gtk_text_buffer_get_iter_at_mark(textbuffer, &iter,
 		gtk_text_buffer_get_insert(textbuffer));
 	num = gtk_text_iter_get_line(&iter) + 1;
